@@ -5,6 +5,7 @@
 #' @param input_id The input_id of the material_dropdown.
 #' @param value The value to set for the material_dropdown.
 #' @param choices The choices to set for the material_dropdown.
+#' @seealso \code{\link{material_dropdown}}
 #' @examples
 #' \dontrun{
 #' update_material_dropdown(
@@ -73,7 +74,7 @@ update_material_dropdown <- function(session, input_id, value = NULL, choices =
   valueShow <- gsub(pattern = " ", replacement = "_shinymaterialdropdownspace_", x = value, fixed = TRUE)
   
   value_js_code <- paste0(
-    "$(", paste0("'#", input_id, "'"), ").find('option[value=", paste0("DOUBLEQUOTE", valueShow, "DOUBLEQUOTE"), "]').prop('selected', true);$(", paste0("'#", input_id, "'"), ").material_select();Shiny.onInputChange('", input_id, "', '", value, "');"
+    "$(", paste0("'#", input_id, "'"), ").find('option[value=", paste0("DOUBLEQUOTE", valueShow, "DOUBLEQUOTE"), "]').prop('selected', true);$(", paste0("'#", input_id, "'"), ").formSelect();Shiny.onInputChange('", input_id, "', '", value, "');"
   )
   
   value_js_code <- gsub(pattern = "DOUBLEQUOTE", replacement = '"', x = value_js_code)
